==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/event/auth/corp/AppDevelopCallBackDTO.java <==
package com.fasc.open.api.event.auth.corp;

/**
 * @author hukc
 * @date 2024年01月12日
 */
public class AppDevelopCallBackDTO {

    private String eventTime;
    /**
     * 企业在应用中的唯一标识。长度最大64个字符。
     */
    private String clientCorpId;
    /**
     * 用户的openCorpId
     */
    private String openCorpId;
    /**
     * 创建的应用appId
     */
    private String appId;
    /**
     * 应用授权码
     */
    private String appAuthCode;
    /**
     * 是否成功创建应用：
     * success：成功
     * failed：失败
     */
    private String status;
    /**
     * 创建应用失败原因，如：企业可用应用数不足
     */
    private String failedReason;
    /**
     * 操作类型：
     * entrust：建立委托关系
     * cancel：取消委托关系
     */
    private String type;

    public String getEventTime() {
        return eventTime;
    }

    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public String getClientCorpId() {
        return clientCorpId;
    }

    public void setClientCorpId(String clientCorpId) {
        this.clientCorpId = clientCorpId;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppAuthCode() {
        return appAuthCode;
    }

    public void setAppAuthCode(String appAuthCode) {
        this.appAuthCode = appAuthCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getFailedReason() {
        return failedReason;
    }

    public void setFailedReason(String failedReason) {
        this.failedReason = failedReason;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}

==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/event/auth/corp/AppDevelopCallBackDTO.java <==
package com.fasc.open.api.event.auth.corp;

/**
 * @author hukc
 * @date 2024年01月12日
 */
public class AppDevelopCallBackDTO {

    private String eventTime;
    /**
     * 企业在应用中的唯一标识。长度最大64个字符。
     */
    private String clientCorpId;
    /**
     * 用户的openCorpId
     */
    private String openCorpId;
    /**
     * 创建的应用appId
     */
    private String appId;
    /**
     * 应用授权码
     */
    private String appAuthCode;
    /**
     * 是否成功创建应用：
     * success：成功
     * failed：失败
     */
    private String status;
    /**
     * 创建应用失败原因，如：企业可用应用数不足
     */
    private String failedReason;

    private String appStatus ;
    /**
     * 操作类型：
     * entrust：建立委托关系
     * cancel：取消委托关系
     */
    private String type;

    public String getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(String appStatus) {
        this.appStatus = appStatus;
    }

    public String getEventTime() {
        return eventTime;
    }

    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public String getClientCorpId() {
        return clientCorpId;
    }

    public void setClientCorpId(String clientCorpId) {
        this.clientCorpId = clientCorpId;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getAppAuthCode() {
        return appAuthCode;
    }

    public void setAppAuthCode(String appAuthCode) {
        this.appAuthCode = appAuthCode;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getFailedReason() {
        return failedReason;
    }

    public void setFailedReason(String failedReason) {
        this.failedReason = failedReason;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}
